import React, { useEffect, useState, RefObject } from 'react';
import * as d3 from 'd3';

const BarChart = () => {
    const ref: RefObject<HTMLDivElement> = React.createRef();

    const dataShow = [
        { Country: "Russia", Value: 420000 },
        { Country: "France", Value: 190000 },
        { Country: "United-State", Value: 330000 },
        { Country: "Brazil", Value: 280000 },
        { Country: "Germany", Value: 200000 },
        { Country: "United-Kingdom", Value: 150000 },
        { Country: "China", Value: 350000 }
    ];

    const [data, setData] = useState(dataShow);

    useEffect(() => {
        draw();
    });

    const draw = () => {
        const container = ref.current;
        if (!container) return;

        var margin = { top: 30, right: 30, bottom: 70, left: 60 },
                    width = 460 - margin.left - margin.right,
                    height = 400 - margin.top - margin.bottom;

        var svg = d3.select(container)
                    .append("svg")
                    .attr("width", width + margin.left + margin.right)
                    .attr("height", height + margin.top + margin.bottom)
                    .append("g")
                    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

        // X axis
        var x = d3.scaleBand()
                .range([0, width])
                .domain(
                    data.map(function (d: any) {
                        return d.Country;
                    })
                )
                .padding(0.2);

        svg.append("g")
            .attr("transform", "translate(0," + height + ")")
            .call(d3.axisBottom(x))
            .selectAll("text")
            .attr("transform", "translate(-10,0)rotate(-45)")
            .style("text-anchor", "end");

        // Y axis
        var max = Math.max(...data.map(o => o.Value)) + 10000
        var y = d3.scaleLinear().domain([0, max]).range([height, 0]);

        svg.append("g").call(d3.axisLeft(y));

        // Data
        svg.selectAll(".block")
            .data(dataShow)
            .enter()
            .append("rect")
            .attr("class", "bar")
            .attr("x", function (d: any) {
                return x(d.Country);
            })
            .attr("width", x.bandwidth())
            .attr("y", function (d: any) {
                return y(d.Value);
            })
            .attr("height", function (d: any) {
                return height - y(d.Value);
            })
            .attr("fill", "#69b3a2");
    }

    return (
        <div className="BarChart" ref={ref}>
            <p>
                <label>Choisissez un intervalle : </label>
                <select name="sort">
                    <option value="">Choisissez une option</option>
                    <option value="day">Jour</option>
                    <option value="week">Semaine</option>
                    <option value="month">Mois</option>
                    <option value="year">Année</option>
                </select>
            </p>
            
            <p>
                <label>Date de début : </label>
                <input type="date" id="start" name="trip-start" value="2022-12-30" min="2018-01-01" max="2021-12-31"/>
            </p>

            <p>
                <label>Date de fin : </label>
                <input type="date" id="end" name="trip-end" value="2022-12-30" min="2018-01-01" max="2021-12-31"/>
            </p>
        </div>
    );
}

export default BarChart;